.. _part:examples:

.. include:: ../../examples/README.rst

Selected Examples
=================

Many :term:`FiPy` :mod:`examples` are primarily used for integration
testing.  The following examples are curated to help with understanding how
:term:`FiPy` is used.

Diffusion Examples
------------------

Selected illustrations of diffusion problems.

* :mod:`examples.diffusion.mesh1D`
* :mod:`examples.diffusion.coupled`
* :mod:`examples.diffusion.mesh20x20`
* :mod:`examples.diffusion.circle`
* :mod:`examples.diffusion.electrostatics`
* :mod:`examples.diffusion.nthOrder.input4thOrder1D`
* :mod:`examples.diffusion.anisotropy`

Convection Examples
-------------------

Selected illustrations of convection problems.

* :mod:`examples.convection.exponential1D.mesh1D`
* :mod:`examples.convection.exponential1DSource.mesh1D`
* :mod:`examples.convection.robin`
* :mod:`examples.convection.source`

Phase Field Examples
--------------------

Selected illustrations of phase field (Allen-Cahn) moving interface
problems.

* :mod:`examples.phase.simple`
* :mod:`examples.phase.binary`
* :mod:`examples.phase.binaryCoupled`
* :mod:`examples.phase.quaternary`
* :mod:`examples.phase.anisotropy`
* :mod:`examples.phase.impingement.mesh40x1`
* :mod:`examples.phase.impingement.mesh20x20`
* :mod:`examples.phase.polyxtal`
* :mod:`examples.phase.polyxtalCoupled`

Level Set Examples
------------------

Selected illustrations of level-set moving interface problems.

* :mod:`examples.levelSet.distanceFunction.mesh1D`
* :mod:`examples.levelSet.distanceFunction.circle`
* :mod:`examples.levelSet.advection.mesh1D`
* :mod:`examples.levelSet.advection.circle`

Cahn-Hilliard Examples
----------------------

Selected illustrations of Cahn-Hilliard (spinodal decomposition) problems.

* :mod:`examples.cahnHilliard.mesh2DCoupled`
* :mod:`examples.cahnHilliard.sphere`

Fluid Flow Examples
-------------------

Selected illustrations of fluid flow problems.

* :mod:`examples.flow.stokesCavity`

Reactive Wetting Examples
-------------------------

Selected illustrations of multi-phase evolution.

* :mod:`examples.reactiveWetting.liquidVapor1D`

.. _sec:UpdateFiPy:

Updating FiPy
-------------

Demonstrations of how to migrate from older versions of :term:`FiPy`.

* :mod:`examples.updating.update2_0to3_0`
* :mod:`examples.updating.update1_0to2_0`
* :mod:`examples.updating.update0_1to1_0`
